@@ -31,16 +31,15 @@
 #'   `BERT`, `DeBERTa-V2`, etc.), to implement a new one see p.4 Implement A Custom Transformer in
 #'   [Transformers for Developers](https://fberding.github.io/aifeducation/articles/transformers.html)
 #'
-#' @param ml_framework `r paramDesc.ml_framework()`
-#' @param text_dataset `r paramDesc.text_dataset()`
-#' @param sustain_track `r paramDesc.sustain_track()`
-#' @param sustain_iso_code `r paramDesc.sustain_iso_code()`
-#' @param sustain_region `r paramDesc.sustain_region()`
-#' @param sustain_interval `r paramDesc.sustain_interval()`
-#' @param trace `r paramDesc.trace()`
-#' @param pytorch_safetensors `r paramDesc.pytorch_safetensors()`
-#' @param log_dir `r paramDesc.log_dir()`
-#' @param log_write_interval `r paramDesc.log_write_interval()`
+#' @param text_dataset `r get_param_doc_desc("text_dataset")`
+#' @param sustain_track `r get_param_doc_desc("sustain_track")`
+#' @param sustain_iso_code `r get_param_doc_desc("sustain_iso_code")`
+#' @param sustain_region `r get_param_doc_desc("sustain_region")`
+#' @param sustain_interval `r get_param_doc_desc("sustain_interval")`
+#' @param trace `r get_param_doc_desc("trace")`
+#' @param pytorch_safetensors `r get_param_doc_desc("pytorch_safetensors")`
+#' @param log_dir `r get_param_doc_desc("log_dir")`
+#' @param log_write_interval `r get_param_doc_desclog_write_interval
 #'
 #' @references Hugging Face transformers documantation:
 #'   * [BERT](https://huggingface.co/docs/transformers/model_doc/bert)
@@ -50,7 +49,7 @@
 #'   * [RoBERTa](https://huggingface.co/docs/transformers/model_doc/roberta)
 #'   * [MPNet](https://huggingface.co/docs/transformers/model_doc/mpnet)
 #'
-#' @family Transformers for developers
+#' @family R6 classes for transformers
 #' @export
 .AIFEBaseTransformer <- R6::R6Class( # nolint
   classname = ".AIFEBaseTransformer",
@@ -139,8 +138,7 @@
     # Other ----
 
     # Initializes the 'static' parameters of the transformer in the `param` list
-    init_common_model_params = function(ml_framework,
-                                        sustain_track,
+    init_common_model_params = function(sustain_track,
                                         sustain_iso_code,
                                         sustain_region,
                                         sustain_interval,
@@ -149,7 +147,6 @@
                                         log_dir,
                                         log_write_interval,
                                         text_dataset) {
-      self$set_model_param("ml_framework", ml_framework)
       self$set_model_param("sustain_track", sustain_track)
       self$set_model_param("sustain_iso_code", sustain_iso_code)
       self$set_model_param("sustain_region", sustain_region)
@@ -166,15 +163,10 @@
     define_required_SFC_functions = function() {
       if (!is.function(private$steps_for_creation$save_transformer_model)) {
         private$steps_for_creation$save_transformer_model <- function(self) {
-          if (self$params$ml_framework == "tensorflow") {
-            self$temp$model$build()
-            self$temp$model$save_pretrained(save_directory = self$params$model_dir)
-          } else {
-            self$temp$model$save_pretrained(
-              save_directory = self$params$model_dir,
-              safe_serilization = self$temp$pt_safe_save
-            )
-          }
+          self$temp$model$save_pretrained(
+            save_directory = self$params$model_dir,
+            safe_serilization = self$temp$pt_safe_save
+          )
         }
       }
     },
@@ -205,7 +197,6 @@
       # SFT: create_chunks_for_training ---------------------------------------------
       if (!is.function(private$steps_for_training$create_chunks_for_training)) {
         private$steps_for_training$create_chunks_for_training <- function(self) {
-
           tokenized_texts_raw <- tokenize_dataset(
             dataset = self$temp$raw_text_dataset,
             tokenizer = self$temp$tokenizer,
@@ -244,23 +235,19 @@
         # For mpnet transformer see AIFEMpnetTransformer -> SFT -> create_data_collator
         private$steps_for_training$create_data_collator <- function(self) {
           if (self$params$whole_word) {
-
             self$temp$data_collator <- transformers$DataCollatorForWholeWordMask(
               tokenizer = self$temp$tokenizer,
               mlm = TRUE,
               mlm_probability = self$params$p_mask,
               return_tensors = self$temp$return_tensors
             )
-
           } else {
-
             self$temp$data_collator <- transformers$DataCollatorForLanguageModeling(
               tokenizer = self$temp$tokenizer,
               mlm = TRUE,
               mlm_probability = self$params$p_mask,
               return_tensors = self$temp$return_tensors
             )
-
           }
         }
       }
@@ -272,14 +259,13 @@
           msg <- ifelse(self$params$whole_word, "Using Whole Word Masking", "Using Token Masking")
           print_message(msg, self$params$trace)
 
-          self$temp$return_tensors <- ifelse(self$params$ml_framework == "tensorflow", "tf", "pt")
+          self$temp$return_tensors <- "pt"
 
           # Create data collator
           private$steps_for_training$create_data_collator(self)
 
           # ----
-          format_type <- ifelse(self$params$ml_framework == "tensorflow", "tensorflow", "torch")
-          self$temp$tokenized_dataset$set_format(type = format_type)
+          self$temp$tokenized_dataset$set_format(type = "torch")
           self$temp$tokenized_dataset <- self$temp$tokenized_dataset$train_test_split(
             test_size = self$params$val_size
           )
@@ -287,13 +273,8 @@
           print_message("Preparing Training of the Model", self$params$trace)
           # Create Custom Callbacks ----
 
-          if (self$params$ml_framework == "tensorflow") {
-            run_py_file("keras_callbacks.py")
-            create_logger <- py$create_AIFETransformerCSVLogger_TF
-          } else {
-            run_py_file("pytorch_transformer_callbacks.py")
-            create_logger <- py$create_AIFETransformerCSVLogger_PT
-          }
+          run_py_file("pytorch_transformer_callbacks.py")
+          create_logger <- py$create_AIFETransformerCSVLogger_PT
 
           logger_args <- list(
             loss_file = self$temp$loss_file,
@@ -305,53 +286,9 @@
           )
           logger <- do.call(create_logger, logger_args)
 
-
-          if (self$params$ml_framework == "tensorflow") { # TENSORFLOW --------------
-            self$temp$tf_train_dataset <- self$temp$model$prepare_tf_dataset(
-              dataset = self$temp$tokenized_dataset$train,
-              batch_size = as.integer(self$params$batch_size),
-              collate_fn = self$temp$data_collator,
-              shuffle = TRUE
-            )
-            self$temp$tf_test_dataset <- self$temp$model$prepare_tf_dataset(
-              dataset = self$temp$tokenized_dataset$test,
-              batch_size = as.integer(self$params$batch_size),
-              collate_fn = self$temp$data_collator,
-              shuffle = TRUE
-            )
-
-            adam <- tf$keras$optimizers$Adam
-
-            # Create Callbacks ---------------------------------------------------------
-            callback_checkpoint <- tf$keras$callbacks$ModelCheckpoint(
-              filepath = paste0(self$params$output_dir, "/checkpoints/best_weights.h5"),
-              monitor = "val_loss",
-              verbose = as.integer(min(self$params$keras_trace, 1)),
-              mode = "auto",
-              save_best_only = TRUE,
-              save_freq = "epoch",
-              save_weights_only = TRUE
-            )
-
-            callback_history <- tf$keras$callbacks$CSVLogger(
-              filename = paste0(self$params$output_dir, "/checkpoints/history.log"),
-              separator = ",",
-              append = FALSE
-            )
-
-            # Add Callbacks
-            self$temp$callbacks <- list(callback_checkpoint, callback_history, logger)
-
-            print_message("Compile Model", self$params$trace)
-            self$temp$model$compile(optimizer = adam(self$params$learning_rate), loss = "auto")
-
-            # Clear session to provide enough resources for computations ---------------
-            tf$keras$backend$clear_session()
-          } else { # PYTORCH ------------------
-
-            if(utils::compareVersion(transformers["__version__"],"4.46.0")>=0){
+          if (check_versions(a = get_py_package_version("transformers"), operator = ">=", b = "4.46.0")) {
             training_args <- transformers$TrainingArguments(
-              output_dir = paste0(self$params$output_dir, "/checkpoints"),
+              output_dir = private$dir_checkpoint,
               overwrite_output_dir = TRUE,
               eval_strategy = "epoch",
               num_train_epochs = as.integer(self$params$n_epoch),
@@ -367,59 +304,59 @@
               auto_find_batch_size = FALSE,
               report_to = "none",
               log_level = "error",
+              disable_tqdm = !self$params$pytorch_trace,
+              dataloader_pin_memory = torch$cuda$is_available()
+            )
+          } else {
+            training_args <- transformers$TrainingArguments(
+              output_dir = private$dir_checkpoint,
+              overwrite_output_dir = TRUE,
+              evaluation_strategy = "epoch",
+              num_train_epochs = as.integer(self$params$n_epoch),
+              logging_strategy = "epoch",
+              save_strategy = "epoch",
+              save_total_limit = as.integer(1),
+              load_best_model_at_end = TRUE,
+              optim = "adamw_torch",
+              learning_rate = self$params$learning_rate,
+              per_device_train_batch_size = as.integer(self$params$batch_size),
+              per_device_eval_batch_size = as.integer(self$params$batch_size),
+              save_safetensors = TRUE,
+              auto_find_batch_size = FALSE,
+              report_to = "none",
+              log_level = "error",
               disable_tqdm = !self$params$pytorch_trace
             )
-            } else {
-              training_args <- transformers$TrainingArguments(
-                output_dir = paste0(self$params$output_dir, "/checkpoints"),
-                overwrite_output_dir = TRUE,
-                evaluation_strategy  = "epoch",
-                num_train_epochs = as.integer(self$params$n_epoch),
-                logging_strategy = "epoch",
-                save_strategy = "epoch",
-                save_total_limit = as.integer(1),
-                load_best_model_at_end = TRUE,
-                optim = "adamw_torch",
-                learning_rate = self$params$learning_rate,
-                per_device_train_batch_size = as.integer(self$params$batch_size),
-                per_device_eval_batch_size = as.integer(self$params$batch_size),
-                save_safetensors = TRUE,
-                auto_find_batch_size = FALSE,
-                report_to = "none",
-                log_level = "error",
-                disable_tqdm = !self$params$pytorch_trace
-              )
-            }
-
-            if(utils::compareVersion(transformers["__version__"],"4.46.0")>=0){
-              self$temp$trainer <- transformers$Trainer(
-                model = self$temp$model,
-                train_dataset = self$temp$tokenized_dataset$train,
-                eval_dataset = self$temp$tokenized_dataset$test,
-                args = training_args,
-                data_collator = self$temp$data_collator,
-                processing_class  = self$temp$tokenizer
-              )
-            } else {
-              self$temp$trainer <- transformers$Trainer(
-                model = self$temp$model,
-                train_dataset = self$temp$tokenized_dataset$train,
-                eval_dataset = self$temp$tokenized_dataset$test,
-                args = training_args,
-                data_collator = self$temp$data_collator,
-                tokenizer = self$temp$tokenizer
-              )
-            }
-
-            self$temp$trainer$remove_callback(transformers$integrations$CodeCarbonCallback)
-            if (!as.logical(self$params$pytorch_trace)) {
-              self$temp$trainer$remove_callback(transformers$PrinterCallback)
-              self$temp$trainer$remove_callback(transformers$ProgressCallback)
-            }
-
-            # Add Callbacks
-            self$temp$trainer$add_callback(logger)
           }
+
+          if (check_versions(a = get_py_package_version("transformers"), operator = ">=", b = "4.46.0")) {
+            self$temp$trainer <- transformers$Trainer(
+              model = self$temp$model,
+              train_dataset = self$temp$tokenized_dataset$train,
+              eval_dataset = self$temp$tokenized_dataset$test,
+              args = training_args,
+              data_collator = self$temp$data_collator,
+              processing_class = self$temp$tokenizer
+            )
+          } else {
+            self$temp$trainer <- transformers$Trainer(
+              model = self$temp$model,
+              train_dataset = self$temp$tokenized_dataset$train,
+              eval_dataset = self$temp$tokenized_dataset$test,
+              args = training_args,
+              data_collator = self$temp$data_collator,
+              tokenizer = self$temp$tokenizer
+            )
+          }
+
+          self$temp$trainer$remove_callback(transformers$integrations$CodeCarbonCallback)
+          if (!as.logical(self$params$pytorch_trace)) {
+            self$temp$trainer$remove_callback(transformers$PrinterCallback)
+            self$temp$trainer$remove_callback(transformers$ProgressCallback)
+          }
+
+          # Add Callbacks
+          self$temp$trainer$add_callback(logger)
         }
       }
 
@@ -427,45 +364,24 @@
       # SFT: start_training ---------------------------------------------------------
       if (!is.function(private$steps_for_training$start_training)) {
         private$steps_for_training$start_training <- function(self) {
-          if (self$params$ml_framework == "tensorflow") { # TENSORFLOW --------------
-            self$temp$model$fit(
-              x = self$temp$tf_train_dataset,
-              validation_data = self$temp$tf_test_dataset,
-              epochs = as.integer(self$params$n_epoch),
-              workers = as.integer(self$params$n_workers),
-              use_multiprocessing = self$params$multi_process,
-              callbacks = list(self$temp$callbacks),
-              verbose = as.integer(self$params$keras_trace)
-            )
-
-            print_message("Load Weights From Best Checkpoint", self$params$trace)
-            self$temp$model$load_weights(paste0(self$params$output_dir, "/checkpoints/best_weights.h5"))
-          } else { # PYTORCH -----------------
-            if (is.function(private$steps_for_training$cuda_empty_cache)) {
-              private$steps_for_training$cuda_empty_cache()
-            }
-            self$temp$trainer$train()
+          if (is.function(private$steps_for_training$cuda_empty_cache)) {
+            private$steps_for_training$cuda_empty_cache()
           }
+          private$create_checkpoint_directory()
+          self$temp$trainer$train()
+          private$clean_checkpoint_directory()
         }
       }
 
-
       # SFT: save_model -------------------------------------------------------------
       if (!is.function(private$steps_for_training$save_model)) {
         private$steps_for_training$save_model <- function(self) {
-          if (self$params$ml_framework == "tensorflow") { # TENSORFLOW --------------
-            self$temp$model$save_pretrained(
-              save_directory = self$params$output_dir
-            )
-            history_log <- read.csv(file = paste0(self$params$output_dir, "/checkpoints/history.log"))
-          } else { # PYTORCH -----------------
-            self$temp$model$save_pretrained(
-              save_directory = self$params$output_dir,
-              safe_serilization = self$temp$pt_safe_save
-            )
-            history_log <- pandas$DataFrame(self$temp$trainer$state$log_history)
-            history_log <- clean_pytorch_log_transformers(history_log)
-          }
+          self$temp$model$save_pretrained(
+            save_directory = self$params$output_dir,
+            safe_serilization = self$temp$pt_safe_save
+          )
+          history_log <- pandas$DataFrame(self$temp$trainer$state$log_history)
+          history_log <- clean_pytorch_log_transformers(history_log)
 
           # Write history log
           write.csv2(
@@ -481,12 +397,9 @@
 
     # Creates a sustainability tracker and stores it in the private `sustainability_tracker` attribute
     create_sustain_tracker = function() {
-
-      tmp_code_carbon<-reticulate::import("codecarbon")
-      codecarbon_version=as.character(tmp_code_carbon["__version__"])
-      if(utils::compareVersion(codecarbon_version,"2.8.0")>=0){
-        path_look_file=codecarbon$lock$LOCKFILE
-        if(file.exists(path_look_file)){
+      if (check_versions(a = get_py_package_version("codecarbon"), operator = ">=", b = "2.8.0")) {
+        path_look_file <- codecarbon$lock$LOCKFILE
+        if (file.exists(path_look_file)) {
           unlink(path_look_file)
         }
       }
@@ -497,7 +410,8 @@
         log_level = "warning",
         measure_power_secs = self$params$sustain_interval,
         save_to_file = FALSE,
-        save_to_api = FALSE
+        save_to_api = FALSE,
+        allow_multiple_runs = FALSE
       )
     },
 
@@ -559,6 +473,31 @@
           step = step
         )
       )
+    },
+
+    # Field for saving the path to the folder string temp files
+    dir_checkpoint = NULL,
+
+    # Create directory in temp files of saving checkpoints
+    create_checkpoint_directory = function() {
+      # Create a directory for the package
+      tmp_dir <- create_and_get_tmp_dir()
+
+      # Create a folder for the current task
+      private$dir_checkpoint <- paste0(
+        tmp_dir, "/",
+        generate_id(16)
+      )
+      create_dir(dir = private$dir_checkpoint, trace = FALSE)
+    },
+
+    # Clean directory for temp files
+    clean_checkpoint_directory = function() {
+      unlink(
+        x = private$dir_checkpoint,
+        recursive = TRUE,
+        force = FALSE
+      )
     }
   ),
   public = list(
@@ -571,7 +510,6 @@
     #'   ### **'Static' parameters**
     #'
     #'   Regardless of the transformer, the following parameters are always included:
-    #'   * `ml_framework`
     #'   * `text_dataset`
     #'   * `sustain_track`
     #'   * `sustain_iso_code`
@@ -643,6 +581,15 @@
       stop("Cannot create .AIFEBaseTransformer objects.")
     },
 
+    #' @description Method to execute while initializing a new transformer.
+    #' @param title `string` A new title.
+    #' @param init_trace `bool` option to show prints. If `TRUE` (by default) - messages will be shown, otherwise
+    #'   (`FALSE`) - hidden.
+    #' @return This method returns nothing.s
+    init_transformer = function(title, init_trace) {
+      self$set_title(title)
+      if (init_trace) print(paste(title, "has been initialized."))
+    },
 
     # Setters ----
 
@@ -759,20 +706,19 @@
     #'   * `raw_text_dataset`
     #'   * `tokenizer`
     #'
-    #' @param model_dir `r paramDesc.model_dir()`
-    #' @param vocab_size `r paramDesc.vocab_size()`
-    #' @param max_position_embeddings `r paramDesc.max_position_embeddings()`
-    #' @param hidden_size `r paramDesc.hidden_size()`
-    #' @param num_attention_heads `r paramDesc.num_attention_heads()`
-    #' @param intermediate_size `r paramDesc.intermediate_size()`
-    #' @param hidden_act `r paramDesc.hidden_act()`
-    #' @param hidden_dropout_prob `r paramDesc.hidden_dropout_prob()`
-    #' @param attention_probs_dropout_prob `r paramDesc.attention_probs_dropout_prob()`
+    #' @param model_dir `r get_param_doc_desc("model_dir")`
+    #' @param vocab_size `r get_param_doc_desc("vocab_size")`
+    #' @param max_position_embeddings `r get_param_doc_desc("max_position_embeddings")`
+    #' @param hidden_size `r get_param_doc_desc("hidden_size")`
+    #' @param num_attention_heads `r get_param_doc_desc("num_attention_heads")`
+    #' @param intermediate_size `r get_param_doc_desc("intermediate_size")`
+    #' @param hidden_act `r get_param_doc_desc("hidden_act")`
+    #' @param hidden_dropout_prob `r get_param_doc_desc("hidden_dropout_prob")`
+    #' @param attention_probs_dropout_prob `r get_param_doc_desc("attention_probs_dropout_prob")`
     #'
     #' @return This method does not return an object. Instead, it saves the configuration and vocabulary of the new
     #'   model to disk.
-    create = function(ml_framework,
-                      model_dir,
+    create = function(model_dir,
                       text_dataset,
                       vocab_size,
                       max_position_embeddings,
@@ -795,7 +741,6 @@
         # Init model parameters -----------------------------------------------------
         # Each transformer has these parameters ----
         private$init_common_model_params(
-          ml_framework,
           sustain_track, sustain_iso_code, sustain_region, sustain_interval,
           trace, pytorch_safetensors,
           log_dir, log_write_interval,
@@ -838,18 +783,17 @@
         if (is.function(private$steps_for_creation$check_max_pos_emb)) {
           private$steps_for_creation$check_max_pos_emb(self)
         }
-        check_class(text_dataset, "LargeDataSetForText", FALSE)
+        check_class(object = text_dataset, object_name = "text_dataset", classes = "LargeDataSetForText", allow_NULL = FALSE)
         self$temp$raw_text_dataset <- text_dataset$get_dataset()
         if (is.null(self$temp$raw_text_dataset$features$text)) {
           stop("Dataset does not contain a column 'text' storing the raw texts.")
         }
 
-        check.ml_framework(ml_framework)
         check.hidden_act(hidden_act)
         check.sustain_iso_code(sustain_iso_code, sustain_track)
 
         # Check possible save formats
-        self$temp$pt_safe_save <- check.possible_save_formats(ml_framework, pytorch_safetensors)
+        self$temp$pt_safe_save <- check.possible_save_formats(pytorch_safetensors)
 
         # Start Sustainability Tracking ---------------------------------------------
         last_log <- py$write_log_py(
@@ -1024,29 +968,25 @@
     #'   * `tokenized_dataset`
     #'   * `tokenizer`
     #'
-    #' @param output_dir `r paramDesc.output_dir()`
-    #' @param model_dir_path `r paramDesc.model_dir_path()`
-    #' @param p_mask `r paramDesc.p_mask()`
-    #' @param whole_word `r paramDesc.whole_word()`
-    #' @param val_size `r paramDesc.val_size()`
-    #' @param n_epoch `r paramDesc.n_epoch()`
-    #' @param batch_size `r paramDesc.batch_size()`
-    #' @param chunk_size `r paramDesc.chunk_size()`
-    #' @param full_sequences_only `r paramDesc.full_sequences_only()`
-    #' @param min_seq_len `r paramDesc.min_seq_len()`
-    #' @param learning_rate `r paramDesc.learning_rate()`
-    #' @param n_workers `r paramDesc.n_workers()`
-    #' @param multi_process `r paramDesc.multi_process()`
-    #' @param keras_trace `r paramDesc.keras_trace()`
-    #' @param pytorch_trace `r paramDesc.pytorch_trace()`
+    #' @param output_dir `r get_param_doc_desc("output_dir")`
+    #' @param model_dir_path `r get_param_doc_desc("model_dir_path")`
+    #' @param p_mask `r get_param_doc_desc("p_mask")`
+    #' @param whole_word `r get_param_doc_desc("whole_word")`
+    #' @param val_size `r get_param_doc_desc("val_size")`
+    #' @param n_epoch `r get_param_doc_desc("n_epoch")`
+    #' @param batch_size `r get_param_doc_desc("batch_size")`
+    #' @param chunk_size `r get_param_doc_desc("chunk_size")`
+    #' @param full_sequences_only `r get_param_doc_desc("full_sequences_only")`
+    #' @param min_seq_len `r get_param_doc_desc("min_seq_len")`
+    #' @param learning_rate `r get_param_doc_desc("learning_rate")`
+    #' @param pytorch_trace ``r get_param_doc_desc("pytorch_trace")`
     #'
     #' @return This method does not return an object. Instead, it saves the configuration and vocabulary of the new
     #'   model to disk.
     #'
     #' @importFrom utils write.csv
     #' @importFrom utils read.csv
-    train = function(ml_framework,
-                     output_dir,
+    train = function(output_dir,
                      model_dir_path,
                      text_dataset,
                      p_mask,
@@ -1058,14 +998,11 @@
                      full_sequences_only,
                      min_seq_len,
                      learning_rate,
-                     n_workers,
-                     multi_process,
                      sustain_track,
                      sustain_iso_code,
                      sustain_region,
                      sustain_interval,
                      trace,
-                     keras_trace,
                      pytorch_trace,
                      pytorch_safetensors,
                      log_dir,
@@ -1075,7 +1012,6 @@
         # Init model parameters -----------------------------------------------------
         # Each transformer has these parameters ----
         private$init_common_model_params(
-          ml_framework,
           sustain_track, sustain_iso_code, sustain_region, sustain_interval,
           trace, pytorch_safetensors,
           log_dir, log_write_interval,
@@ -1093,9 +1029,6 @@
         self$set_model_param("full_sequences_only", full_sequences_only)
         self$set_model_param("min_seq_len", min_seq_len)
         self$set_model_param("learning_rate", learning_rate)
-        self$set_model_param("n_workers", n_workers)
-        self$set_model_param("multi_process", multi_process)
-        self$set_model_param("keras_trace", keras_trace)
         self$set_model_param("pytorch_trace", pytorch_trace)
 
         # Check defining of required functions ----
@@ -1124,14 +1057,13 @@
         )
 
         # argument checking ---------------------------------------------------------
-        check.ml_framework(ml_framework)
 
-        model_files_check <- check.model_files(ml_framework, model_dir_path)
+        model_files_check <- check.model_files(model_dir_path)
         self$temp$from_pt <- model_files_check$from_pt
         self$temp$from_tf <- model_files_check$from_tf
         self$temp$load_safe <- model_files_check$load_safe
 
-        check_class(text_dataset, "LargeDataSetForText", FALSE)
+        check_class(object = text_dataset, object_name = "text_dataset", classes = "LargeDataSetForText", allow_NULL = FALSE)
         self$temp$raw_text_dataset <- text_dataset$get_dataset()
         if (is.null(self$temp$raw_text_dataset$features$text)) {
           stop("Dataset does not contain a column 'text' storing the texts for training.")
@@ -1140,7 +1072,7 @@
         check.sustain_iso_code(sustain_iso_code, sustain_track)
 
         # Check possible save formats
-        self$temp$pt_safe_save <- check.possible_save_formats(ml_framework, pytorch_safetensors)
+        self$temp$pt_safe_save <- check.possible_save_formats(pytorch_safetensors)
 
         last_log <- py$write_log_py(
           self$temp$log_file,
@@ -1190,14 +1122,18 @@
         last_log <- py$write_log_py(
           self$temp$log_file,
           value_top = 4, total_top = total,
-          message_top = paste(private$title, "Overall: Creating Chunks of Sequences & Calculating Tokenizer Statistics"),
+          message_top = paste(
+            private$title, "Overall: Creating Chunks of Sequences & Calculating Tokenizer Statistics"
+          ),
           last_log = last_log, write_interval = write_interval
         )
 
         self$temp$write_interval <- write_interval
         self$temp$value_top <- 4
         self$temp$total_top <- total
-        self$temp$message_top <- paste(private$title, "Overall: Creating Chunks of Sequences & Calculating Tokenizer Statistics")
+        self$temp$message_top <- paste(
+          private$title, "Overall: Creating Chunks of Sequences & Calculating Tokenizer Statistics"
+        )
 
         print_message("Creating Chunks of Sequences for Training", trace)
         private$steps_for_training$create_chunks_for_training(self)
@@ -1214,7 +1150,7 @@
         )
 
         create_dir(output_dir, trace, "Creating Output Directory")
-        create_dir(paste0(output_dir, "/checkpoints"), trace, "Creating Checkpoint Directory")
+        # create_dir(paste0(output_dir, "/checkpoints"), trace, "Creating Checkpoint Directory")
 
         private$steps_for_training$prepare_train_tune(self)
 
